@@ -6,6 +6,7 @@ use crate::mutations::insert_op_scratch;
 use crate::mutations::set_validation_status;
 use crate::prelude::mutations_helpers::insert_valid_authored_op;
 use crate::query::test_data::EntryTestData;
+use ::fixt::prelude::*;
 
 use super::*;
 
@@ -15,6 +16,7 @@ async fn can_handle_update_in_scratch() {
     let mut scratch = Scratch::new();
     let mut conn = Connection::open_in_memory().unwrap();
     SCHEMA_CELL.initialize(&mut conn, None).unwrap();
+    let zome = fixt!(Zome);
 
     let mut txn = conn
         .transaction_with_behavior(TransactionBehavior::Exclusive)
@@ -41,6 +43,7 @@ async fn can_handle_update_in_scratch() {
     // - Add to the scratch
     insert_op_scratch(
         &mut scratch,
+        Some(zome),
         td.update_store_entry_op.clone(),
         ChainTopOrdering::default(),
     )
